# Operations

```{py:currentmodule} jeta.archive.operations
```
## Operations API Classes
### Public Operation API Functions
```{eval-rst}
.. autofunction:: backup
```
```{eval-rst}
.. autofunction:: restore
```
```{eval-rst}
.. autofunction:: truncate
```
```{eval-rst}
.. autofunction:: destory
```
```{eval-rst}
.. autofunction:: add_msid_to_archive
```
```{eval-rst}
.. autofunction:: initialize
```
### Private Operation API Functions (Not To Be Called Directly)
```{eval-rst}
.. autofunction:: _create_archive_database
```
```{eval-rst}
.. autofunction:: _create_root_content
```
```{eval-rst}
.. autofunction:: _create_msid_index
```
```{eval-rst}
.. autofunction:: _create_msid_dataset
```
```{eval-rst}
.. autofunction:: _create_archive_files
```
```{eval-rst}
.. autofunction:: _create_msid_directory
```
